@@ -14,10 +14,8 @@
 
 """mrack default app."""
 #  pylint: disable=no-name-in-module
-import asyncio
 import logging
 import sys
-from functools import update_wrapper
 from typing import Set, Tuple, Type
 
 import click
@@ -29,15 +27,10 @@ from mrack.actions.output import Output
 from mrack.actions.ssh import SSH
 from mrack.actions.up import Up
 from mrack.context import GlobalContext, global_context
-from mrack.errors import (
-    ApplicationError,
-    ConfigError,
-    MetadataError,
-    ProviderError,
-    ValidationError,
-)
+from mrack.errors import ApplicationError, MrackError
 from mrack.providers import providers
 from mrack.providers.provider import Provider
+from mrack.utils import async_run
 from mrack.version import VERSION
 
 PROVIDER_NAME = 0
@@ -96,17 +89,6 @@ except ModuleNotFoundError as err:
     logger.debug(IMPORT_ERR_TEMPLATE, err.name)
 
 
-def async_run(func):
-    """Decorate click actions to run as async."""
-    func = asyncio.coroutine(func)
-
-    def wrapper(*args, **kwargs):
-        loop = asyncio.get_event_loop()
-        return loop.run_until_complete(func(*args, **kwargs))
-
-    return update_wrapper(wrapper, func)
-
-
 def init_providers():
     """Register all providers usable in this session."""
     if not installed_providers:
@@ -248,11 +230,7 @@ def exception_handler(func):
             ret_code = func(*args, **kwargs)
         except (
             FileNotFoundError,
-            ConfigError,
-            MetadataError,
-            ValidationError,
-            ProviderError,
-            ApplicationError,
+            MrackError,
         ) as known_error:
             logger.error(known_error)
             sys.exit(1)
