@@ -90,6 +90,11 @@ class AWSTransformer(Transformer):
 
         return []
 
+    def validate_host(self, host):
+        """Validate host input that it contains what AWS needs."""
+        super().validate_host(host)
+        self.validate_ownership_and_lifetime(host)
+
     def create_host_requirement(self, host):
         """Create single input for AWS provisioner."""
         del_vol = self._find_value(
@@ -107,4 +112,5 @@ class AWSTransformer(Transformer):
             "subnet_ids": self._find_subnet_ids(host),
         }
 
+        req = self.update_metadata_for_owner_lifetime(req)
         return req
